
.. image:: ../data/treetime-logo-small.png
   :align: left
   
*TreeTime* is a general data organisation, management and analysis tool using linked trees instead of flat lists of tables.
A tree is a hierarchical structure that arranges your data into units and sub-units.
Mathematical functions (sum, difference, mean, ratio) can be calculated recursively.
Linked trees are distinct trees that share data between them.
In *TreeTime*, a data object is part of several trees at the same time.

Content
-------

.. toctree::
   :maxdepth: 2

   introduction
   meta-structure
   data-format
   data-fields
   tree-fields
   releases

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
